@@ -20,8 +20,8 @@ function args(experiment_name, reset) {
 describe('FlaskSplit.finished', function () {
     before(function () {
         global.$ = {
-            post: function () {
-                this.last_args = arguments;
+            ajax: function () {
+                this.last_args = Array.prototype.slice.call(arguments);
             },
         }
     });
@@ -36,14 +36,17 @@ describe('FlaskSplit.finished', function () {
     it('validates the reset argument', function () {
         throws(finished, args(undefined, 1), /must be true, false/);
     });
-    it('calls $.post', function () {
+    it('calls $.ajax', function () {
+        var ajax_args;
         finished.apply(FS, args('experiment', false));
-        assert.equal($.last_args.length, 4);
+        assert.equal($.last_args.length, 2);
         assert.equal($.last_args[0], '/split-js/finished');
-        assert.deepEqual($.last_args[1], {
-            experiment_name: 'experiment',
-            reset: false
-        });
-        assert.equal($.last_args[3], 'json');
+        ajax_args = $.last_args[1];
+        assert.equal(ajax_args.accepts, 'application/json');
+        assert.equal(ajax_args.contentType, 'application/json; charset=UTF-8');
+        assert.equal(ajax_args.data, '{"experiment_name":"experiment","reset":false}');
+        assert.equal(ajax_args.dataType, 'json');
+        assert.equal(ajax_args.processData, false);
+        assert.equal(ajax_args.type, 'POST');
     });
 });
